=================================================
ASK SMAPI Model - Model definitions for SMAPI SDK
=================================================

ask-smapi-model is the model definitions package for Skill Management APIs (SMAPI) by
the Software Development Kit (SDK) team for Python. It allows Python developers
to model the requests, responses and related JSON structures, as defined in
`SMAPI Documentation <https://developer.amazon.com/docs/smapi/smapi-overview.html>`_.

Getting Help
------------

The model definitions in this package are auto-generated. The issues and pull requests
on the repository are not monitored and may get closed without investigation. Please use
these community resources for getting help:

* Use the `ASK SDK <https://github.com/alexa-labs/alexa-skills-kit-sdk-for-python>`_ for building skills and filing bugs.
* Request and vote for `Alexa features <https://alexa.uservoice.com/forums/906892-alexa-skills-developer-voice-and-vote>`_!
